==> jc-1.4.0.tar.gz: java/awt/font/TextLayout__24CaretPolicy.h <==
// public class java.awt.font.TextLayout$CaretPolicy

// class file dependencies
// @dep_class d2158fad11ed751d java_awt_font_TextLayout__24CaretPolicy
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_font_TextLayout__24CaretPolicy_H_
#define _JC_java_awt_font_TextLayout__24CaretPolicy_H_

// Forward structure declarations
struct _jc_java_awt_font_TextHitInfo$object;
struct _jc_java_awt_font_TextLayout$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_font_TextLayout__24CaretPolicy$sub_refs	_jc_java_awt_font_TextLayout__24CaretPolicy$sub_refs;
typedef struct _jc_java_awt_font_TextLayout__24CaretPolicy$sub_nonrefs	_jc_java_awt_font_TextLayout__24CaretPolicy$sub_nonrefs;
typedef struct _jc_java_awt_font_TextLayout__24CaretPolicy$refs	_jc_java_awt_font_TextLayout__24CaretPolicy$refs;
typedef struct _jc_java_awt_font_TextLayout__24CaretPolicy$nonrefs	_jc_java_awt_font_TextLayout__24CaretPolicy$nonrefs;
typedef struct _jc_java_awt_font_TextLayout__24CaretPolicy$object	_jc_java_awt_font_TextLayout__24CaretPolicy$object;

typedef const struct _jc_java_awt_font_TextLayout__24CaretPolicy$vmethods	_jc_java_awt_font_TextLayout__24CaretPolicy$vmethods;
typedef const struct _jc_java_awt_font_TextLayout__24CaretPolicy$vtable	_jc_java_awt_font_TextLayout__24CaretPolicy$vtable;
typedef const struct _jc_java_awt_font_TextLayout__24CaretPolicy$vtype	_jc_java_awt_font_TextLayout__24CaretPolicy$vtype;

// Constructors
extern void _jc_java_awt_font_TextLayout__24CaretPolicy$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_font_TextLayout__24CaretPolicy$object *);

// Virtual methods
extern struct _jc_java_awt_font_TextHitInfo$object *_jc_java_awt_font_TextLayout__24CaretPolicy$method$getStrongCaret$f695232b1bb61e91(_jc_env *, struct _jc_java_awt_font_TextLayout__24CaretPolicy$object *, struct _jc_java_awt_font_TextHitInfo$object *, struct _jc_java_awt_font_TextHitInfo$object *, struct _jc_java_awt_font_TextLayout$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_font_TextLayout__24CaretPolicy$method_info$getStrongCaret$f695232b1bb61e91;

// Virtual methods structure
struct _jc_java_awt_font_TextLayout__24CaretPolicy$vmethods {
	struct _jc_java_awt_font_TextHitInfo$object	*(*getStrongCaret$f695232b1bb61e91)(_jc_env *, struct _jc_java_awt_font_TextLayout__24CaretPolicy$object *, struct _jc_java_awt_font_TextHitInfo$object *, struct _jc_java_awt_font_TextHitInfo$object *, struct _jc_java_awt_font_TextLayout$object *);
};

// Vtable
struct _jc_java_awt_font_TextLayout__24CaretPolicy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_font_TextLayout__24CaretPolicy$vmethods	java_awt_font_TextLayout__24CaretPolicy;
};

// Vtype
struct _jc_java_awt_font_TextLayout__24CaretPolicy$vtype {
	_jc_type			type;
	_jc_java_awt_font_TextLayout__24CaretPolicy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_font_TextLayout__24CaretPolicy$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_font_TextLayout__24CaretPolicy$refs {
    _jc_java_awt_font_TextLayout__24CaretPolicy$sub_refs	java_awt_font_TextLayout__24CaretPolicy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_font_TextLayout__24CaretPolicy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_font_TextLayout__24CaretPolicy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_font_TextLayout__24CaretPolicy$sub_nonrefs	java_awt_font_TextLayout__24CaretPolicy;
};

// Object instance structure
struct _jc_java_awt_font_TextLayout__24CaretPolicy$object {
	_jc_java_awt_font_TextLayout__24CaretPolicy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_font_TextLayout__24CaretPolicy$vtype	*vtype;
	_jc_java_awt_font_TextLayout__24CaretPolicy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_font_TextLayout__24CaretPolicy$vtype _jc_java_awt_font_TextLayout__24CaretPolicy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_font_TextLayout__24CaretPolicy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_font_TextLayout__24CaretPolicy$class_object;

#endif	/* _JC_java_awt_font_TextLayout__24CaretPolicy_H_ */

==> jc-1.4.6.tar.gz: java/awt/font/TextLayout__24CaretPolicy.h <==
// public class java.awt.font.TextLayout$CaretPolicy

// class file dependencies
// @dep_class d2158fad11ed751d java_awt_font_TextLayout__24CaretPolicy
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_font_TextLayout__24CaretPolicy_H_
#define _JC_java_awt_font_TextLayout__24CaretPolicy_H_

// Forward structure declarations
struct _jc_java_awt_font_TextHitInfo$object;
struct _jc_java_awt_font_TextLayout$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_font_TextLayout__24CaretPolicy$sub_refs	_jc_java_awt_font_TextLayout__24CaretPolicy$sub_refs;
typedef struct _jc_java_awt_font_TextLayout__24CaretPolicy$sub_nonrefs	_jc_java_awt_font_TextLayout__24CaretPolicy$sub_nonrefs;
typedef struct _jc_java_awt_font_TextLayout__24CaretPolicy$refs	_jc_java_awt_font_TextLayout__24CaretPolicy$refs;
typedef struct _jc_java_awt_font_TextLayout__24CaretPolicy$nonrefs	_jc_java_awt_font_TextLayout__24CaretPolicy$nonrefs;
typedef struct _jc_java_awt_font_TextLayout__24CaretPolicy$object	_jc_java_awt_font_TextLayout__24CaretPolicy$object;

typedef const struct _jc_java_awt_font_TextLayout__24CaretPolicy$vmethods	_jc_java_awt_font_TextLayout__24CaretPolicy$vmethods;
typedef const struct _jc_java_awt_font_TextLayout__24CaretPolicy$vtable	_jc_java_awt_font_TextLayout__24CaretPolicy$vtable;
typedef const struct _jc_java_awt_font_TextLayout__24CaretPolicy$vtype	_jc_java_awt_font_TextLayout__24CaretPolicy$vtype;

// Constructors
extern void _jc_java_awt_font_TextLayout__24CaretPolicy$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_font_TextLayout__24CaretPolicy$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_font_TextHitInfo$object *_jc_java_awt_font_TextLayout__24CaretPolicy$method$getStrongCaret$f695232b1bb61e91(_jc_env *, struct _jc_java_awt_font_TextLayout__24CaretPolicy$object *, struct _jc_java_awt_font_TextHitInfo$object *, struct _jc_java_awt_font_TextHitInfo$object *, struct _jc_java_awt_font_TextLayout$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_font_TextLayout__24CaretPolicy$method_info$getStrongCaret$f695232b1bb61e91;

// Virtual methods structure
struct _jc_java_awt_font_TextLayout__24CaretPolicy$vmethods {
	struct _jc_java_awt_font_TextHitInfo$object	*(*getStrongCaret$f695232b1bb61e91)(_jc_env *, struct _jc_java_awt_font_TextLayout__24CaretPolicy$object *, struct _jc_java_awt_font_TextHitInfo$object *, struct _jc_java_awt_font_TextHitInfo$object *, struct _jc_java_awt_font_TextLayout$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_font_TextLayout__24CaretPolicy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_font_TextLayout__24CaretPolicy$vmethods	java_awt_font_TextLayout__24CaretPolicy;
};

// Vtype
struct _jc_java_awt_font_TextLayout__24CaretPolicy$vtype {
	_jc_type			type;
	_jc_java_awt_font_TextLayout__24CaretPolicy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_font_TextLayout__24CaretPolicy$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_font_TextLayout__24CaretPolicy$refs {
    _jc_java_awt_font_TextLayout__24CaretPolicy$sub_refs	java_awt_font_TextLayout__24CaretPolicy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_font_TextLayout__24CaretPolicy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_font_TextLayout__24CaretPolicy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_font_TextLayout__24CaretPolicy$sub_nonrefs	java_awt_font_TextLayout__24CaretPolicy;
};

// Object instance structure
struct _jc_java_awt_font_TextLayout__24CaretPolicy$object {
	_jc_java_awt_font_TextLayout__24CaretPolicy$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_font_TextLayout__24CaretPolicy$vtype	*vtype;
	_jc_java_awt_font_TextLayout__24CaretPolicy$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_font_TextLayout__24CaretPolicy$vtype _jc_java_awt_font_TextLayout__24CaretPolicy$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_font_TextLayout__24CaretPolicy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_font_TextLayout__24CaretPolicy$class_object;

#endif	/* _JC_java_awt_font_TextLayout__24CaretPolicy_H_ */
